# This is free and unencumbered software released into the public domain.
# See https://unlicense.org/ for details.

__author__ = u'Curtis Rueden'
__email__ = u'ctrueden@gmail.com'
__copyright__ = u'Public domain'
__license__ = u'License :: OSI Approved :: Unlicense'

__version__ = u'1.1.0'
__status__ = u'Stable'

__PACKAGE_TITLE__ = u'iBroadcast'
__PACKAGE_NAME__ = u'ibroadcast'
__PACKAGE_DESCRIPTION__ = u'iBroadcast Python client'
__PACKAGE_URL__ = u'https://github.com/ctrueden/ibroadcast-python'
